# This example shows a window with 5 elements:
# - A dropdown list, named "com_port", with different COM ports.
# - A dropdown list, named "test", with different tests.
# - A button, named "exec_one" (with same text), to execute only one test.
# - A button, named "exec_all"(with same text), to execute all tests.
# - A label, named "result"(with same text) with the test/s result.
import wx
import serial
import time

class MyFrame(wx.Frame):
    def __init__(self, parent, id, title):
        wx.Frame.__init__(self, parent, id, title)

        # Add a panel so it looks the correct on all platforms
        panel = wx.Panel(self, wx.ID_ANY)

        # create the controls
        self.com_port = wx.ComboBox(panel, wx.ID_ANY, choices=["COM1", "COM2", "COM3", "COM4", "COM5", "COM6", "COM7", "COM8"], style=wx.CB_DROPDOWN|wx.CB_READONLY)
        self.test = wx.ComboBox(panel, wx.ID_ANY, choices=["Test 1", "Test 2", "Test 3"], style=wx.CB_DROPDOWN|wx.CB_READONLY)
        self.exec_one = wx.Button(panel, wx.ID_ANY, label="Execute One")
        self.exec_all = wx.Button(panel, wx.ID_ANY, label="Execute All")
        self.result = wx.StaticText(panel, wx.ID_ANY, label="Result:")

        # setup the layout with sizers
        hsizer = wx.BoxSizer(wx.HORIZONTAL)
        vsizer = wx.BoxSizer(wx.VERTICAL)

        vsizer.Add(self.com_port, 0, wx.ALL|wx.EXPAND, 5)
        vsizer.Add(self.test, 0, wx.ALL|wx.EXPAND, 5)
        vsizer.Add(self.exec_one, 0, wx.ALL|wx.EXPAND, 5)
        vsizer.Add(self.exec_all, 0, wx.ALL|wx.EXPAND, 5)
        vsizer.Add(self.result, 0, wx.ALL|wx.EXPAND, 5)

        hsizer.Add(vsizer, 0, wx.ALL|wx.EXPAND, 5)

        panel.SetSizer(hsizer)
        panel.Layout()

        # Bind controls to events
        self.Bind(wx.EVT_COMBOBOX, self.EvtComboBox, self.com_port)
        self.Bind(wx.EVT_BUTTON, self.EvtButtonExecOne, self.exec_one)
        self.Bind(wx.EVT_BUTTON, self.EvtButtonExecAll, self.exec_all)

    def EvtComboBox(self, event):
        print( 'EvtComboBox: %s\n' % event.GetString() )

    def EvtButtonExecOne(self, event):
        print( 'EvtButtonExecOne: %s\n' % event.GetString() )

    def EvtButtonExecAll(self, event):
        print( 'EvtButtonExecAll: %s\n' % event.GetString() )

class MyApp(wx.App):
    def OnInit(self):
        frame = MyFrame(None, wx.ID_ANY, 'Small editor')
        self.SetTopWindow(frame)

        print( "Print statements go to this stdout window by default." )

        frame.Show(True)
        return True

app = MyApp(redirect=True)
app.MainLoop()